#
# spec file for package sysconfig
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sysconfig
Version:        0.83.9
Release:        0
Summary:        The sysconfig scheme for traditional network scripts
License:        GPL-2.0+
Group:          System/Base
Url:            https://github.com/openSUSE/sysconfig
PreReq:         %fillup_prereq %insserv_prereq textutils fileutils gawk sed grep
BuildRequires:  libtool
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} >= 1230
BuildRequires:  pkgconfig(systemd)
%define         udevdir	/usr/lib/udev
%else
%define         udevdir	/lib/udev
%endif
Source:         %name-%version.tar.bz2
Requires:       /sbin/ifup
Requires:       /sbin/netconfig
Requires:       sysvinit(network)
Recommends:     wicked-service

%description
This package provides the SUSE system configuration scheme for the
traditional "ifup" alias "netcontrol" network scripts.

Authors:
--------
    Olaf Kirch <okir@suse.de>
    Bjoern Jacke <bjoern@j3e.de>
    Mads Martin Joergensen <mmj@suse.de>
    Peter Poeml <poeml@suse.de>
    Arvin Schnell <arvin@suse.de>
    Michal Svec <msvec@suse.cz>
    Christian Zoz <zoz@suse.de>
    Werner Fink <werner@suse.de>
    Hannes Reinecke <hare@suse.de>
    Marius Tomaschewski <mt@suse.de>

%package netconfig
Summary:        Script to apply network provided settings
Group:          System/Base
Requires(pre):  sysconfig = %{version}
Provides:       /sbin/netconfig
Requires:       /bin/logger

%description netconfig
This package provides the netconfig scripts to apply network
provided settings like DNS or NIS into system files.

Authors:
--------
    Michael Calmer <mc@suse.de>
    Marius Tomaschewski <mt@suse.de>
    Milisav Radmanic <radmanic@suse.de>


%prep
%setup -n sysconfig-%{version}

%build
autoreconf --force --install
CFLAGS="$RPM_OPT_FLAGS -fPIC" \
./configure --prefix=/ \
            --sbindir=/sbin \
            --libdir=/%_lib \
            --sysconfdir=%_sysconfdir \
            --mandir=%_mandir \
            --with-unitdir=%_unitdir \
            --with-udevdir=%udevdir \
            --with-fillup-templatesdir=/var/adm/fillup-templates
%{__make} %{?_smp_mflags}

%check
make check

%clean
rm -rf $RPM_BUILD_ROOT

%install
make DESTDIR=$RPM_BUILD_ROOT install
touch $RPM_BUILD_ROOT/etc/sysconfig/network/config
touch $RPM_BUILD_ROOT/etc/sysconfig/network/dhcp
mkdir -p $RPM_BUILD_ROOT/sbin
ln -s /sbin/service $RPM_BUILD_ROOT/sbin/rcnetwork

%files
%defattr(-,root,root)
%dir /etc/modprobe.d
%config /etc/modprobe.d/50-blacklist.conf
%config /etc/sysconfig/network/ifcfg.template
%ghost /etc/sysconfig/network/config
%ghost /etc/sysconfig/network/dhcp
%dir /usr/share/doc/packages/sysconfig
%doc /usr/share/doc/packages/sysconfig/Contents
%doc /usr/share/doc/packages/sysconfig/COPYING
/etc/sysconfig/network/scripts/functions.rpm-utils
/var/adm/fillup-templates/sysconfig.dhcp-network
/var/adm/fillup-templates/sysconfig.config-network
/usr/share/omc/svcinfo.d/network.xml
/sbin/rcnetwork
/sbin/ifuser
%dir %attr(0750,root,dialout) %_sysconfdir/ppp
%dir %_sysconfdir/ppp/ip-up.d
%dir %_sysconfdir/ppp/ip-down.d
%dir %_sysconfdir/ppp/ipv6-up.d
%dir %_sysconfdir/ppp/ipv6-down.d
%dir %_sysconfdir/ppp/pre-start.d
%dir %_sysconfdir/ppp/post-stop.d
%_sysconfdir/ppp/ip-up
%_sysconfdir/ppp/ip-down
%_sysconfdir/ppp/ipv6-up
%_sysconfdir/ppp/ipv6-down
%_sysconfdir/ppp/post-stop
%_sysconfdir/ppp/pre-start

%files netconfig
%defattr(-,root,root)
%dir /etc/netconfig.d
/etc/netconfig.d/*
/etc/sysconfig/network/scripts/functions.netconfig
/sbin/netconfig
/usr/share/man/man8/netconfig.8.gz
%doc /usr/share/doc/packages/sysconfig/netconfig.png
%_sysconfdir/ppp/netconfig
%_sysconfdir/ppp/ip-up.d/10-netconfig
%_sysconfdir/ppp/ip-down.d/90-netconfig
%_sysconfdir/ppp/pre-start.d/10-netconfig
%_sysconfdir/ppp/post-stop.d/90-netconfig

%pre
# package update ?
if [ ${1:-0} -gt 1 ]; then
	# trigger update from < 0.80.x only (-> openSUSE 12.3),
	# (guard for variable added to network/config later...)
	if [ -x /usr/sbin/NetworkManager ] && grep -qs "^NETWORKMANAGER=" \
		var/adm/fillup-templates/sysconfig.config-network ; then
		mkdir -p /dev/.sysconfig/network/ && \
		grep -s "^NETWORKMANAGER=" etc/sysconfig/network/config \
			> /dev/.sysconfig/network/migrate_nm_variable || :
	elif [ -f /dev/.sysconfig/network/migrate_nm_variable ] ; then
		rm -f /dev/.sysconfig/network/migrate_nm_variable || :
	fi
fi

%post
#
## we provide own, improved variant of the remove_and_set suse
## rpm macro that is able to handle files in subdirs, and more
. etc/sysconfig/network/scripts/functions.rpm-utils
#
# remove obsolete sysconfig-network specific variables
sysconfig_remove_and_set network/config NOZEROCONF
sysconfig_remove_and_set network/config LINKLOCAL_INTERFACES
sysconfig_remove_and_set network/config IFPLUGD_OPTIONS
sysconfig_remove_and_set network/config DEFAULT_BROADCAST
sysconfig_remove_and_set network/config FORCE_PERSISTENT_NAMES
sysconfig_remove_and_set network/config MANDATORY_DEVICES
sysconfig_remove_and_set network/config USE_SYSLOG
sysconfig_remove_and_set network/dhcp   DHCLIENT_BIN
sysconfig_remove_and_set network/dhcp   DHCLIENT6_BIN
sysconfig_remove_and_set network/dhcp   DHCLIENT_DEBUG
sysconfig_remove_and_set network/dhcp   DHCLIENT_WAIT_LINK
sysconfig_remove_and_set network/dhcp   DHCLIENT_USER_OPTIONS
sysconfig_remove_and_set network/dhcp   DHCLIENT_PRIMARY_DEVICE
sysconfig_remove_and_set network/dhcp   DHCLIENT6_USER_OPTIONS
sysconfig_remove_and_set network/dhcp   DHCPCD_USER_OPTIONS
sysconfig_remove_and_set network/dhcp   DHCP6C_USER_OPTIONS
##
%{fillup_only -dns dhcp network network}
%{fillup_only -dns config network network}
/sbin/ldconfig
# remove obsolete dhcp and per interface variables
_umask=`umask`
for file in etc/sysconfig/network/dhcp etc/sysconfig/network/ifcfg-* ; do
	name="${file##*\/ifcfg-}"
	case $name in
	(lo|""|*" "*|*~|*.old|*.rpmnew|*.rpmsave|*.scpmbackup) continue ;;
	esac
	case $file in
		(*/ifcfg-*) umask 0177 ;;
	esac
	sysconfig_remove_and_set -b "" $file \
		DHCLIENT_MODIFY_NTP_CONF     \
		DHCLIENT_ADDITIONAL_OPTIONS  \
		DHCLIENT_SCRIPT_EXE
	umask $_umask
done
# be a little bit paranoid and set the correct mode even we set umask
chmod 0600 etc/sysconfig/network/ifcfg-* 2>/dev/null || :
# bnc#803058: migrate from NETWORKMANAGER=yes/no variable to
#             network.service alias link masking rcnetwork.
if [ -f /dev/.sysconfig/network/migrate_nm_variable -a -x /usr/bin/systemctl ] ; then
	. /dev/.sysconfig/network/migrate_nm_variable
	case $NETWORKMANAGER in
	no)
		# NetworkManager.service were always started before; stop
		# and disable it, so /etc/init.d/network isn't masked...
		# kill all, NM is using KillMode=Process (bnc#895447)
		/usr/bin/systemctl --kill-who=all kill NetworkManager.service || :
		/usr/bin/systemctl stop NetworkManager.service || :
		/usr/bin/systemctl --force disable NetworkManager.service || :
		rm -f /dev/.sysconfig/network/migrate_nm_variable || :
	;;
	yes)
		# Keep the /dev/.sysconfig/network/migrate_nm_variable file,
		# as hint for migration in NetworkManager post-install ...
		# Mask /etc/init.d/network service until NM update is done.
		/usr/bin/systemctl --force mask network.service || :
	;;
	esac
else
	# cleanup obsolete NETWORKMANAGER variable
	sysconfig_remove_and_set network/config NETWORKMANAGER
fi

%postun
/sbin/ldconfig

%preun
if test "$1" = "0" -a -x /etc/init.d/network ; then
	/etc/init.d/network stop-all-dhcp-clients 2>/dev/null || :
fi

%changelog
